@@ -4,6 +4,7 @@ from .CheckboxList import CheckboxList
 from .ComponentTemplate import ComponentTemplate
 from .Dropdown import Dropdown
 from .ExpandableMenuItem import ExpandableMenuItem
+from .Tabs import Tabs
 from .dropdownArrowDown import dropdownArrowDown
 from .status import status
 from .ComboBox import ComboBox
@@ -17,6 +18,7 @@ __all__ = [
     "ComponentTemplate",
     "Dropdown",
     "ExpandableMenuItem",
+    "Tabs",
     "dropdownArrowDown",
     "status",
     "ComboBox",
